@@ -3,7 +3,16 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-from inspect import getargspec
+try:
+    from inspect import getfullargspec as getargspec
+
+    _USING_GET_FULL_ARG_SPEC = True
+except (AttributeError, ImportError):
+    from inspect import getargspec
+
+    _USING_GET_FULL_ARG_SPEC = False
+
+# from inspect import getargspec
 from string import Formatter
 from collections import OrderedDict
 import re
@@ -21,7 +30,7 @@ from .schema import (
     SchemaValidationError,
 )
 
-from collections import Counter, defaultdict, OrderedDict
+from collections import Counter
 
 import six
 
@@ -52,7 +61,7 @@ class ValidationErrorItem(BaseModel):
 
 
 class ValidationErrorResponse(BaseModel):
-    deatil = ArrayField(ObjectField(ValidationErrorItem))
+    detail = ArrayField(ObjectField(ValidationErrorItem))
 
 
 class PathNotFullfilled(Exception):
